@@ -24,8 +24,8 @@ class Option(object):
         if self.is_required and is_none:
             raise ValueError(
                 "Attribute value error: '{0}', "
-                "" "invalid new value."
-                .format(self.name)
+                ""
+                "invalid new value.".format(self.name)
             )
 
         self.value = new_value
@@ -35,3 +35,11 @@ class Option(object):
 
     def required(self):
         return self.is_required
+
+    def __eq__(self, obj):
+        return (
+            isinstance(obj, Option)
+            and obj.name == self.name
+            and obj.value == self.value
+            and obj.is_required == self.is_required
+        )
